local writing_ft = { "quarto", "pandoc", "markdown", "text", "tex" }

local prose_plugs = {
	-- UI improvements
	-- provide distraction free writing
	{ "folke/zen-mode.nvim", config = true, event = "VeryLazy" },
	-- provide even distraction free-er writing (lowlight paragraphs)
	{ "folke/twilight.nvim", event = "VeryLazy" },
	{
		"andrewferrier/wrapping.nvim",
		config = function()
			require("wrapping").setup({
				create_keymappings = false,
				notify_on_switch = false,
				softener = { markdown = true, text = true, asciidoc = true },
			})
		end,
		lazy = false,
	},
	-- displays prettier headlines mimicking the ones in emacs orgmode
	{
		"lukas-reineke/headlines.nvim",
		dependencies = "nvim-treesitter/nvim-treesitter",
		config = true,
		ft = writing_ft,
	},
	-- generate an auto-updating html preview for md files
	{
		"iamcco/markdown-preview.nvim",
		build = function()
			vim.fn["mkdp#util#install"]()
		end,
		ft = writing_ft,
	},

	-- bring zettelkasten commands
	{
		"mickael-menu/zk-nvim",
		config = function()
			require("zk").setup({ picker = "telescope" })
		end,
		ft = writing_ft,
		cmd = {
			"ZkBacklinks",
			"ZkCd",
			"ZkIndex",
			"ZkInsertLink",
			"ZkInsertLinkAtSelection",
			"ZkLinks",
			"ZkMatch",
			"ZkNew",
			"ZkNewFromContentSelection",
			"ZkNewFromTitleSelection",
			"ZkNotes",
			"ZkTags",
		},
	},
	-- simple static markdown linking and link following using zettel IDs
	{ "marty-oehme/zettelkasten.nvim", ft = writing_ft, event = "VeryLazy" },

	-- syntax highlighting for markdown criticmarkup (comments, additions, ...)
	{ "vim-pandoc/vim-criticmarkup", ft = writing_ft },

	-- create mindmaps from your markdown
	{
		"Zeioth/markmap.nvim",
		cmd = { "MarkmapOpen", "MarkmapSave", "MarkmapWatch", "MarkmapWatchStop" },
		config = true,
	},

	-- cite as you write from papis databases
	-- ADDITIONAL DEPENDENCIES: papis and yq in shell env
	-- {
	-- 	"jghauser/papis.nvim",
	-- 	cond = vim.fn.executable("papis") == 1 and vim.fn.executable("yq") == 1,
	-- 	ft = writing_ft,
	-- 	dependencies = {
	-- 		"kkharji/sqlite.lua",
	-- 		"nvim-lua/plenary.nvim",
	-- 		"MunifTanjim/nui.nvim",
	-- 		"nvim-treesitter/nvim-treesitter",
	-- 	},
	-- 	lazy = false,
	-- 	config = true,
	-- }
}

return prose_plugs
